Girder Worker Utilities
-----------------------

This repository is for use with the Girder-3 version of Girder Worker.  For modern development, it has been moved into Girder core and all new work should be done there.
